@@ -12,7 +12,6 @@ PAYLA_UTILS = {
     ],
     'SERVER_IP': '192.168.1.4',
     'REQUEST_ID_HEADER': 'X-Request-ID',
-    'TRACING_ENABLED': True,
     'RUN_EXTRA_COMMANDS': ['loadinitialusers', 'setup_something'],
     'LOCAL_DJANGO_ADMIN_PASSWORD': os.environ.get('LOCAL_DJANGO_ADMIN_PASSWORD', 'admin'),
     'ENV_THEMES': {
@@ -118,7 +117,6 @@ DEFAULTS: dict = {
     'RUN_EXTRA_COMMANDS': [],
     'LOCAL_DJANGO_ADMIN_PASSWORD': None,
     'REQUEST_ID_HEADER': None,
-    'TRACING_ENABLED': False,
     'SERVER_IP': None,
     'ENV_THEMES': {
         'local.dev': {
